summaryrefslogtreecommitdiffstats
path: root/knotes/KNotesAppIface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /knotes/KNotesAppIface.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'knotes/KNotesAppIface.h')
-rw-r--r--knotes/KNotesAppIface.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/knotes/KNotesAppIface.h b/knotes/KNotesAppIface.h
index f97776fd..7ddfdc28 100644
--- a/knotes/KNotesAppIface.h
+++ b/knotes/KNotesAppIface.h
@@ -32,8 +32,8 @@
#ifndef __KNotesAppIface_h__
#define __KNotesAppIface_h__
-#include <qstring.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqmap.h>
#include <dcopobject.h>
@@ -49,8 +49,8 @@ k_dcop:
* @param text the body of the new note
* @return the new notes' id
*/
- virtual QString newNote( const QString& name = QString::null,
- const QString& text = QString::null ) = 0;
+ virtual TQString newNote( const TQString& name = TQString::null,
+ const TQString& text = TQString::null ) = 0;
/**
* Create a new note and inserts the current text in the clipboard
@@ -60,54 +60,54 @@ k_dcop:
* KNotes will choose an appropriate name
* @return the new notes' id
*/
- virtual QString newNoteFromClipboard( const QString& name = QString::null ) = 0;
+ virtual TQString newNoteFromClipboard( const TQString& name = TQString::null ) = 0;
/**
* Deletes a note forever.
* @param noteId the id of the note to kill
*/
- virtual ASYNC killNote( const QString& noteId ) = 0;
+ virtual ASYNC killNote( const TQString& noteId ) = 0;
/**
* Deletes a note forever.
* @param noteId the id of the note to kill
* @param force do not request confirmation
*/
- virtual ASYNC killNote( const QString& noteId, bool force ) = 0;
+ virtual ASYNC killNote( const TQString& noteId, bool force ) = 0;
/**
* Get all the notes including their ids.
* @return a QMap that maps the id of a note to its name
*/
- virtual QMap<QString,QString> notes() const = 0;
+ virtual TQMap<TQString,TQString> notes() const = 0;
/**
* Changes the title/name of a note.
* @param noteId the id of the note to be modified
* @param newName the new title
*/
- virtual ASYNC setName( const QString& noteId, const QString& newName ) = 0;
+ virtual ASYNC setName( const TQString& noteId, const TQString& newName ) = 0;
/**
* Sets the text of a note. This will delete the old text!
* @param noteId the id of the note
* @param newText the new text for the note
*/
- virtual ASYNC setText( const QString& noteId, const QString& newText ) = 0;
+ virtual ASYNC setText( const TQString& noteId, const TQString& newText ) = 0;
/**
* Returns the foreground/text color of a note.
* @param noteId the id of the note in question
* @return the foreground/text color as a QString
*/
- virtual QString fgColor( const QString& noteId ) const = 0;
+ virtual TQString fgColor( const TQString& noteId ) const = 0;
/**
* Returns the background color of a note.
* @param noteId the id of the note in question
* @return the background color as a QString
*/
- virtual QString bgColor( const QString& noteId ) const = 0;
+ virtual TQString bgColor( const TQString& noteId ) const = 0;
/**
* Sets the color (foreground and background color) of a note.
@@ -115,22 +115,22 @@ k_dcop:
* @param fgColor the new text color for the note
* @param bgColor the new background color for the note
*/
- virtual ASYNC setColor( const QString& noteId, const QString& fgColor,
- const QString& bgColor ) = 0;
+ virtual ASYNC setColor( const TQString& noteId, const TQString& fgColor,
+ const TQString& bgColor ) = 0;
/**
* Returns the title/name of a note.
* @param noteId the id of the note in question
* @return the name as a QString
*/
- virtual QString name( const QString& noteId ) const = 0;
+ virtual TQString name( const TQString& noteId ) const = 0;
/**
* Returns the text of a note.
* @param noteId the id of the note in question
* @return the body as a QString
*/
- virtual QString text( const QString& noteId ) const = 0;
+ virtual TQString text( const TQString& noteId ) const = 0;
/******** HERE STARTS THE KNotesAppIface DCOP INTERFACE EXTENSION ********/
@@ -139,13 +139,13 @@ k_dcop:
* Show a note as if it had been selected from the "notes" menu.
* @param noteId the id of the note to show
*/
- virtual ASYNC showNote( const QString& noteId ) const = 0;
+ virtual ASYNC showNote( const TQString& noteId ) const = 0;
/**
* Hide a note.
* @param noteId the id of the note to hide
*/
- virtual ASYNC hideNote( const QString& noteId ) const = 0;
+ virtual ASYNC hideNote( const TQString& noteId ) const = 0;
/**
* Show all notes on their respective desktops.
@@ -162,14 +162,14 @@ k_dcop:
* @param noteId the id of the note in question
* @return the width as a uint
*/
- virtual int width( const QString& noteId ) const = 0;
+ virtual int width( const TQString& noteId ) const = 0;
/**
* Returns the height of a note.
* @param noteId the id of the note in question
* @return the height as a uint
*/
- virtual int height( const QString& noteId ) const = 0;
+ virtual int height( const TQString& noteId ) const = 0;
/**
* Repositions a note.
@@ -177,7 +177,7 @@ k_dcop:
* @param x the new x-coordinate of the note
* @param y the new y-coordinate of the note
*/
- virtual ASYNC move( const QString& noteId, int x, int y ) const = 0;
+ virtual ASYNC move( const TQString& noteId, int x, int y ) const = 0;
/**
* Changes the size of a note.
@@ -185,13 +185,13 @@ k_dcop:
* @param width the new width of the note
* @param height the new height of the note
*/
- virtual ASYNC resize( const QString& noteId, int width, int height ) const = 0;
+ virtual ASYNC resize( const TQString& noteId, int width, int height ) const = 0;
/**
* This tells KNotes that a specific app has synchronized with all the notes.
* @param app the app that has synced with KNotes
*/
- virtual ASYNC sync( const QString& app ) = 0;
+ virtual ASYNC sync( const TQString& app ) = 0;
/**
* Test if a note was created new after the last sync.
@@ -200,7 +200,7 @@ k_dcop:
* @return true if the note is new, false if not or if the note does
* not exist
*/
- virtual bool isNew( const QString& app, const QString& noteId ) const = 0;
+ virtual bool isNew( const TQString& app, const TQString& noteId ) const = 0;
/**
* Test if a note was modified since the last sync.
@@ -209,7 +209,7 @@ k_dcop:
* @return true if modified (note that this will return true if the note is
* new as well!) and false if the note is not modified or doesn't exist
*/
- virtual bool isModified( const QString& app, const QString& noteId ) const = 0;
+ virtual bool isModified( const TQString& app, const TQString& noteId ) const = 0;
};
#endif
@@ -60,54 +60,54 @@ k_dcop:
/**
* Get all the notes including their ids.
- * @return a QMap that maps the id of a note to its name
+ * @return a TQMap that maps the id of a note to its name
*/